powered by
Make sure all the files needed for the analysis are present in a directory containing simulated data.
validate_filenames(path)
Path to the files.
TRUE, if files in the directory path have names in the expected format; otherwise, an error is thrown.
TRUE
path
Output files from the study must match the pattern PXLY.csv where X is phase number (1-4) and Y is list number (1-8).
PXLY.csv